@@ -130,7 +130,7 @@ class Job(XquteJob, JobCaching):
                 outdir=str(self.outdir),
                 stdout_file=str(self.stdout_file),
                 stderr_file=str(self.stderr_file),
-                lock_file=str(self.lock_file),
+                jid_file=str(self.jid_file),
             ),
             "in": self.input,
             "in_": self.input,
@@ -201,7 +201,7 @@ class Job(XquteJob, JobCaching):
                 outdir=str(self.outdir),
                 stdout_file=str(self.stdout_file),
                 stderr_file=str(self.stderr_file),
-                lock_file=str(self.lock_file),
+                jid_file=str(self.jid_file),
             ),
             "in": self.input,
             "in_": self.input,
